API Reference
=============

.. automodule:: sybil
  :members: Sybil, Region, Example

Documents
---------

.. autoclass:: sybil.Document
  :members:

.. automodule:: sybil.document
  :members: PythonDocument


capture parser
--------------

.. automodule:: sybil.parsers.capture
  :members: parse_captures

:rst:dir:`code-block` parsers
-----------------------------

.. automodule:: sybil.parsers.codeblock
  :members:

:ref:`doctest <doctest-simple-testfile>` parser
-----------------------------------------------

.. automodule:: sybil.parsers.doctest
  :members: DocTestParser

skip parser
--------------

.. automodule:: sybil.parsers.skip
  :members:
